## Version 0.0.4

This new version includes several updates to the documentation and build process, as well as the addition of an all-contributors section. The version also includes a fix to the build command.

### New Features

- Added an all-contributors section to the documentation (9a65f2) (Eric Ma)
- Added an all-contributors badge to the project (71be05) (Eric Ma)
- Added all-contributors configuration to the project (7ae0d2) (Eric Ma)
- Updated the all-contributors specification to correct the project name and owner (3e841c) (Eric Ma)
- Switched to using docs/index.md for all-contributors (0aa0fe) (Eric Ma)

### Bug Fixes

- Fixed the build command for the project (6e8e65) (Eric Ma)

### Deprecations

- Temporarily removed the badge from the project (4bef48) (Eric Ma)

### Other Changes

- Removed unnecessary whitespace from the project (943ba4) (Eric Ma)
- Reformatted the allcontributors.rc file (8ae972) (Eric Ma)
- Updated the badge for the project (6c0850) (Eric Ma)
- Updated the table in the documentation (047481) (Eric Ma)
- Bumped the project version from 0.0.3 to 0.0.4 (943e5a) (Eric Ma)
